#
# spec file for package libogg
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _SO_nr 0
Name:           libogg
Version:        1.3.5
Release:        2.5
Summary:        Ogg Bitstream Library
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://xiph.org/vorbis/
Source:         https://downloads.xiph.org/releases/ogg/%{name}-%{version}.tar.xz
Source2:        baselibs.conf
Patch1:         lib64.dif
Patch2:         m4.diff
BuildRequires:  pkgconfig
BuildRequires:  xz

%description
Libogg is a library for manipulating Ogg bitstreams.  It handles both
making Ogg bitstreams and getting packets from Ogg bitstreams.

Ogg is the native bitstream format of libvorbis (Ogg Vorbis audio
codec) and libtheora (Theora video codec).

%package -n libogg%{_SO_nr}
Summary:        Ogg Bitstream Library
Group:          System/Libraries

%description -n libogg%{_SO_nr}
Libogg is a library for manipulating Ogg bitstreams.  It handles both
making Ogg bitstreams and getting packets from Ogg bitstreams.

Ogg is the native bitstream format of libvorbis (Ogg Vorbis audio
codec) and libtheora (Theora video codec).

%package devel
Summary:        Include Files and Libraries for Ogg Development
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libogg%{_SO_nr} = %{version}

%description devel
This package contains all necessary include files and libraries needed
to compile and develop applications that use libogg.

%prep
%setup -q
%patch -P 2
if [ "%{_lib}" == "lib64" ]; then
%patch -P 1
fi

%build
# Fix optimization level
sed -i s,-O20,-O3,g configure

%configure --disable-static
%make_build

%install
%make_install docdir="%{_docdir}/%{name}-devel"
# remove unneeded files
find %{buildroot} -type f -name "*.la" -delete -print

%check
%make_build check

%post -n libogg%{_SO_nr} -p /sbin/ldconfig
%postun -n libogg%{_SO_nr} -p /sbin/ldconfig

%files -n libogg%{_SO_nr}
%doc AUTHORS CHANGES README.md
%license COPYING
%{_libdir}/libogg.so.%{_SO_nr}*

%files devel
%{_docdir}/%{name}-devel
%{_includedir}/ogg
%{_libdir}/libogg.so
%dir %{_datadir}/aclocal
%{_datadir}/aclocal/ogg.m4
%{_libdir}/pkgconfig/ogg.pc

%changelog
* Thu Feb 29 2024 pgajdos@suse.com
- Use %%patch -P N instead of deprecated %%patchN.
* Sat Jul 17 2021 Dirk Müller <dmueller@suse.com>
- update to 1.3.5:
  * Fix unsigned typedef problem on macOS.
  * Fix overflow check in ogg_sync_buffer.
  * Clean up cmake and autotools build files.
  * Remove Symbian and Apple XCode build files.
  * Fix documentation cross-reference links.
* Sun Sep  1 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.4
  * Faster slice-by-8 CRC32 implementation.
    See https://lwn.net/Articles/453931/ for motivation.
* Tue Mar 27 2018 9+suse@cirno.systems
- Use %%license macro
- Update to version 1.3.3
  * Fix an issue with corrupt continued packet handling.
* Sat Mar 11 2017 jengelh@inai.de
- Orthographic fixes to descriptions. RPM group fix.
* Thu Feb 12 2015 p.drouand@gmail.com
- Update to version 1.3.2
  * Fix an bug in oggpack_writecopy().
* Sun Feb 23 2014 andreas.stieger@gmx.de
- Xiph libogg 1.3.1
  * Guard against very large packets.
  * Respect the configure --docdir override.
  * Documentation fixes.
- fix SLE build
* Sun Dec 25 2011 coolo@suse.com
- own aclocal directory
* Sun Dec 25 2011 idonmez@suse.com
- -O20 optimization level does not exist, use -O3
* Sun Nov 20 2011 reddwarf@opensuse.org
- updated to version 1.3.0
  * Add ogg_stream_flush_fill() call
    This produces longer packets on flush, similar to
    what ogg_stream_pageout_fill() does for single pages.
- run spec-cleaner on it
- remove "SLES10 -> SLES11 upgrade path" parts since the upgrade
  already happened and anyway the entry in bugzilla is not public
* Fri Sep  9 2011 coolo@suse.com
- replace _service with real file
* Wed Dec  8 2010 reddwarf@opensuse.org
- update to version 1.2.2
  * Build fix (types correction) for Mac OS X
  * Update win32 project files to Visual Studio 2008
  * ogg_stream_pageout_fill documentation fix
* Tue Dec  7 2010 reddwarf@opensuse.org
- update to version 1.2.1
  * Various build updates (see SVN)
  * Add ogg_stream_pageout_fill() to API to allow applications
    greater explicit flexibility in page sizing.
  * Documentation updates including multiplexing description,
    terminology and API (incl. ogg_packet_clear(),
    ogg_stream_pageout_fill())
  * Correct possible buffer overwrite in stream encoding on 32 bit
    when a single packet exceed 250MB.
  * Correct read-buffer overrun [without side effects] under
    similar circumstances.
  * Update unit testing to work properly with new page spill
    heuristic.
  * Alter default flushing behavior to span less often and use
    larger page sizes when packet sizes are large.
  * Build fixes for additional compilers
  * Documentation updates
- run spec-cleaner
- removed configure.dif (reapply if -fsigned-char causes problems)
- removed libogg-compile-warning-fix.diff (upstreamed)
* Wed Dec 16 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Sat Aug  1 2009 beineri@opensuse.org
- update to version 1.1.4:
  * New async error reporting mechanism. Calls made after a fatal
    error are now safely handled in the event an error code is ignored
  * Added allocation checks useful to some embedded applications
  * fix possible read past end of buffer when reading 0 bits
  * Updates to API documentation
  * Build fixes
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Sun May 11 2008 coolo@suse.de
- fix rename of xxbit packages
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Sat Aug 11 2007 crrodriguez@suse.de
- really follow the library packaging policy
- run make check
- add missing glibc-devel dependency on -devel package
* Mon Apr 16 2007 tiwai@suse.de
- follow library packaging policy
  * move docs to devel package
  * remove static library
- remove obsoleted m4 files
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 11 2006 tiwai@suse.de
- compile with -fstack-protector.
* Fri Dec  2 2005 tiwai@suse.de
- updated to version 1.1.3.
* Sun Sep  4 2005 aj@suse.de
- Revert last patch, wrong package.
* Sat Sep  3 2005 aj@suse.de
- compile with -fno-strict-aliasing (#115135).
* Thu Jul  7 2005 tiwai@suse.de
- remove -fsigned-char option (#93878).
- fix misc compile warnings.
* Wed Nov 24 2004 tiwai@suse.de
- updated to version 1.1.2.
* Sat Aug 21 2004 schwab@suse.de
- Fix 64bit bugs.
* Wed Jan 21 2004 tiwai@suse.de
- fixed quoting in m4 files.
* Fri Jan  9 2004 adrian@suse.de
- add %%run_ldconfig to %%postun
* Fri Jan  9 2004 tiwai@suse.de
- updated to version 1.1.
- added pkgconfig to neededforbuild.
* Thu Jan  9 2003 kukuk@suse.de
- Add *.la files to -devel filelist
* Thu Sep 19 2002 tiwai@suse.de
- fixed the conflict between the last ogg.m4 fix and 64bit
  fix patches.
- moved devel documents under %%{_docdir}/libogg-devel.
* Tue Sep 17 2002 pthomas@suse.de
- ogg.m4:
  - If prefix is /usr, don't add -I$prefix/include to OGG_CFLAGS
    and don't add -L$prefix/lib to OGG_LIBS. While the latter is
    just unnecessary, the former can be dangerous and will make
    gcc warn.
  - Fix test for prefix.
* Mon Aug 12 2002 tiwai@suse.de
- added Requires %%{name} = %%{version} to devel package.
* Tue Jul 23 2002 tiwai@suse.de
- provides the backward compatible m4 file.
* Mon Jul 22 2002 tiwai@suse.de
- updated to version 1.0.
- clean up the spec file.
- added %%run_ldconfig.
* Mon Jun 10 2002 adrian@suse.de
- fix ogg.m4 for lib64 systems
* Thu Apr 18 2002 kukuk@suse.de
- Add --libdir to configure to compile on x86_64
* Thu Feb  7 2002 tiwai@suse.de
- fixed compile on s390x.
* Fri Jan  4 2002 tiwai@suse.de
- updated to RC3.
  sync with cvs 2002.01.04.
* Tue Dec  4 2001 tiwai@suse.de
- sync with cvs 2001.12.04.
* Wed Oct 24 2001 tiwai@suse.de
- sync with cvs 20011024.
  + fixed documents
- removed Requires to libogg from devel.
* Mon Aug 13 2001 tiwai@suse.de
- updated to 1.0rc2 from cvs 20010813.
* Thu Jun  7 2001 tiwai@suse.de
- fixed build with the recent libtool.
* Mon Mar 12 2001 tiwai@suse.de
- corrected copyright in spec file.
* Mon Feb 26 2001 tiwai@suse.de
- Updated to 1.0beta4.
* Wed Jan 31 2001 tiwai@suse.de
- Initial version: 1.0beta3.
